@@ -275,10 +275,10 @@ wxString CControlSocket::ConvertDomainName(wxString const& domain)
 #elif defined(AI_IDN)
 	return domain;
 #else
-	wxScopedCharBuffer const utf8 = domain.utf8_str();
+	std::string const utf8 = fz::to_utf8(domain);
 
 	char *output = 0;
-	if (idna_to_ascii_8z(utf8, &output, IDNA_ALLOW_UNASSIGNED)) {
+	if (idna_to_ascii_8z(utf8.c_str(), &output, IDNA_ALLOW_UNASSIGNED)) {
 		LogMessage(MessageType::Debug_Warning, _T("Could not convert domain name"));
 		return domain;
 	}
@@ -422,14 +422,10 @@ int CControlSocket::CheckOverwriteFile()
 	return FZ_REPLY_WOULDBLOCK;
 }
 
-CFileTransferOpData::CFileTransferOpData(bool is_download, const wxString& local_file, const wxString& remote_file, const CServerPath& remote_path) :
-	COpData(Command::transfer),
-	localFile(local_file), remoteFile(remote_file), remotePath(remote_path),
-	download(is_download)
-{
-}
-
-CFileTransferOpData::~CFileTransferOpData()
+CFileTransferOpData::CFileTransferOpData(bool is_download, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path)
+	: COpData(Command::transfer)
+	, localFile(local_file), remoteFile(remote_file), remotePath(remote_path)
+	, download(is_download)
 {
 }
 
@@ -840,7 +836,7 @@ void CControlSocket::SendAsyncRequest(CAsyncRequestNotification* pNotification)
 CRealControlSocket::CRealControlSocket(CFileZillaEnginePrivate & engine)
 	: CControlSocket(engine)
 {
-	m_pSocket = new CSocket(this);
+	m_pSocket = new CSocket(engine.GetThreadPool(), this);
 
 	m_pBackend = new CSocketBackend(this, *m_pSocket, engine_.GetRateLimiter());
 	m_pProxyBackend = 0;
@@ -1054,7 +1050,7 @@ int CRealControlSocket::ContinueConnect()
 		m_pProxyBackend = new CProxySocket(this, m_pSocket, this);
 		m_pBackend = m_pProxyBackend;
 		int res = m_pProxyBackend->Handshake(static_cast<CProxySocket::ProxyType>(proxy_type),
-											m_pCurrentServer->GetHost(), m_pCurrentServer->GetPort(),
+											m_pCurrentServer->GetHost().ToStdWstring(), m_pCurrentServer->GetPort(),
 											engine_.GetOptions().GetOption(OPTION_PROXY_USER),
 											engine_.GetOptions().GetOption(OPTION_PROXY_PASS));
 
@@ -1102,17 +1098,16 @@ void CRealControlSocket::ResetSocket()
 {
 	m_pSocket->Close();
 
-	if (m_pSendBuffer)
-	{
+	if (m_pSendBuffer) {
 		delete [] m_pSendBuffer;
 		m_pSendBuffer = 0;
 		m_nSendBufferLen = 0;
 	}
 
-	if (m_pProxyBackend)
-	{
-		if (m_pProxyBackend != m_pBackend)
+	if (m_pProxyBackend) {
+		if (m_pProxyBackend != m_pBackend) {
 			delete m_pProxyBackend;
+		}
 		m_pProxyBackend = 0;
 	}
 	delete m_pBackend;
@@ -1213,6 +1208,15 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 					ResetOperation(FZ_REPLY_INTERNALERROR);
 					return false;
 				}
+				if (!l.ChangePath(pFileExistsNotification->newName)) {
+					ResetOperation(FZ_REPLY_INTERNALERROR);
+					return false;
+				}
+				if (!l.HasParent() || !l.MakeParent(&tmp)) {
+					ResetOperation(FZ_REPLY_INTERNALERROR);
+					return false;
+				}
+				
 				pData->localFile = l.GetPath() + tmp;
 			}
 
@@ -1274,7 +1278,7 @@ bool CControlSocket::SetFileExistsAction(CFileExistsNotification *pFileExistsNot
 	return true;
 }
 
-void CControlSocket::CreateLocalDir(const wxString &local_file)
+void CControlSocket::CreateLocalDir(std::wstring const & local_file)
 {
 	wxString file;
 	CLocalPath local_path(local_file, &file);
@@ -1327,9 +1331,9 @@ int CControlSocket::List(CServerPath, wxString, int)
 	return FZ_REPLY_NOTSUPPORTED;
 }
 
-int CControlSocket::FileTransfer(const wxString, const CServerPath &,
-					const wxString &, bool,
-					const CFileTransferCommand::t_transferSettings&)
+int CControlSocket::FileTransfer(std::wstring const&, CServerPath const&,
+					std::wstring const&, bool,
+					CFileTransferCommand::t_transferSettings const&)
 {
 	return FZ_REPLY_NOTSUPPORTED;
 }
@@ -1339,7 +1343,7 @@ int CControlSocket::RawCommand(const wxString&)
 	return FZ_REPLY_NOTSUPPORTED;
 }
 
-int CControlSocket::Delete(const CServerPath&, std::deque<wxString>&&)
+int CControlSocket::Delete(const CServerPath&, std::deque<std::wstring>&&)
 {
 	return FZ_REPLY_NOTSUPPORTED;
 }
