@@ -27,6 +27,7 @@ CFileZillaEnginePrivate::CFileZillaEnginePrivate(CFileZillaEngineContext& contex
 	, directory_cache_(context.GetDirectoryCache())
 	, path_cache_(context.GetPathCache())
 	, parent_(parent)
+	, thread_pool_(context.GetThreadPool())
 {
 	m_engineList.push_back(this);
 
@@ -81,8 +82,9 @@ CFileZillaEnginePrivate::~CFileZillaEnginePrivate()
 
 	delete m_pLogging;
 
-	if (m_engineList.empty())
+	if (m_engineList.empty()) {
 		CSocket::Cleanup(true);
+	}
 }
 
 void CFileZillaEnginePrivate::OnEngineEvent(EngineNotificationType type)
@@ -181,7 +183,7 @@ void CFileZillaEnginePrivate::SendQueuedLogs(bool reset_flag)
 			queue_logs_ = ShouldQueueLogsFromOptions();
 		}
 
-		if (!m_maySendNotificationEvent || !m_NotificationList.empty()) {
+		if (!m_maySendNotificationEvent || m_NotificationList.empty()) {
 			return;
 		}
 		m_maySendNotificationEvent = false;
@@ -190,7 +192,7 @@ void CFileZillaEnginePrivate::SendQueuedLogs(bool reset_flag)
 	notification_handler_.OnEngineEvent(&parent_);
 }
 
-void CFileZillaEnginePrivate::ClearQueuedLogs(fz::scoped_lock& lock, bool reset_flag)
+void CFileZillaEnginePrivate::ClearQueuedLogs(fz::scoped_lock&, bool reset_flag)
 {
 	for (auto msg : queued_logs_) {
 		delete msg;
@@ -281,7 +283,7 @@ unsigned int CFileZillaEnginePrivate::GetNextAsyncRequestNumber()
 }
 
 // Command handlers
-int CFileZillaEnginePrivate::Connect(const CConnectCommand &command)
+int CFileZillaEnginePrivate::Connect(CConnectCommand const& command)
 {
 	if (IsConnected())
 		return FZ_REPLY_ALREADYCONNECTED;
@@ -314,7 +316,7 @@ int CFileZillaEnginePrivate::Disconnect(CDisconnectCommand const&)
 	return res;
 }
 
-int CFileZillaEnginePrivate::List(const CListCommand &command)
+int CFileZillaEnginePrivate::List(CListCommand const& command)
 {
 	int flags = command.GetFlags();
 	bool const refresh = (command.GetFlags() & LIST_FLAG_REFRESH) != 0;
@@ -354,12 +356,12 @@ int CFileZillaEnginePrivate::List(const CListCommand &command)
 	return m_pControlSocket->List(command.GetPath(), command.GetSubDir(), flags);
 }
 
-int CFileZillaEnginePrivate::FileTransfer(const CFileTransferCommand &command)
+int CFileZillaEnginePrivate::FileTransfer(CFileTransferCommand const& command)
 {
 	return m_pControlSocket->FileTransfer(command.GetLocalFile(), command.GetRemotePath(), command.GetRemoteFile(), command.Download(), command.GetTransferSettings());
 }
 
-int CFileZillaEnginePrivate::RawCommand(const CRawCommand& command)
+int CFileZillaEnginePrivate::RawCommand(CRawCommand const& command)
 {
 	{
 		fz::scoped_lock lock(notification_mutex_);
@@ -379,22 +381,22 @@ int CFileZillaEnginePrivate::Delete(CDeleteCommand& command)
 	return m_pControlSocket->Delete(command.GetPath(), command.ExtractFiles());
 }
 
-int CFileZillaEnginePrivate::RemoveDir(const CRemoveDirCommand& command)
+int CFileZillaEnginePrivate::RemoveDir(CRemoveDirCommand const& command)
 {
 	return m_pControlSocket->RemoveDir(command.GetPath(), command.GetSubDir());
 }
 
-int CFileZillaEnginePrivate::Mkdir(const CMkdirCommand& command)
+int CFileZillaEnginePrivate::Mkdir(CMkdirCommand const& command)
 {
 	return m_pControlSocket->Mkdir(command.GetPath());
 }
 
-int CFileZillaEnginePrivate::Rename(const CRenameCommand& command)
+int CFileZillaEnginePrivate::Rename(CRenameCommand const& command)
 {
 	return m_pControlSocket->Rename(command);
 }
 
-int CFileZillaEnginePrivate::Chmod(const CChmodCommand& command)
+int CFileZillaEnginePrivate::Chmod(CChmodCommand const& command)
 {
 	return m_pControlSocket->Chmod(command);
 }
@@ -838,11 +840,12 @@ int CFileZillaEnginePrivate::Cancel()
 void CFileZillaEnginePrivate::OnOptionsChanged(changed_options_t const&)
 {
 	bool queue_logs = ShouldQueueLogsFromOptions();
-	fz::scoped_lock lock(notification_mutex_);
-	queue_logs_ = queue_logs;
-
-	if (!queue_logs_) {
-		SendQueuedLogs();
+	if (queue_logs) {
+		fz::scoped_lock lock(notification_mutex_);
+		queue_logs_ = true;
+	}
+	else {
+		SendQueuedLogs(true);
 	}
 }
 
