@@ -5,11 +5,10 @@
 #include "httpcontrolsocket.h"
 #include "tlssocket.h"
 
+#include <libfilezilla/file.hpp>
 #include <libfilezilla/iputils.hpp>
 #include <libfilezilla/local_filesys.hpp>
 
-#include <wx/file.h>
-
 #define FZ_REPLY_REDIRECTED FZ_REPLY_ALREADYCONNECTED
 
 // Connect is special for HTTP: It is done on a per-command basis, so we need
@@ -69,34 +68,24 @@ public:
 class CHttpFileTransferOpData : public CFileTransferOpData, public CHttpOpData
 {
 public:
-	CHttpFileTransferOpData(bool is_download, const wxString& local_file, const wxString& remote_file, const CServerPath& remote_path)
-		: CFileTransferOpData(is_download, local_file, remote_file, remote_path), CHttpOpData(this)
+	CHttpFileTransferOpData(bool is_download, std::wstring const& local_file, std::wstring const& remote_file, const CServerPath& remote_path)
+		: CFileTransferOpData(is_download, local_file, remote_file, remote_path)
+		, CHttpOpData(this)
 	{
-		pFile = 0;
 	}
 
-	virtual ~CHttpFileTransferOpData()
-	{
-		delete pFile;
-	}
-
-	wxFile* pFile;
+	fz::file file;
 };
 
 CHttpControlSocket::CHttpControlSocket(CFileZillaEnginePrivate & engine)
 	: CRealControlSocket(engine)
 {
-	m_pRecvBuffer = 0;
-	m_recvBufferPos = 0;
-	m_pTlsSocket = 0;
-	m_pHttpOpData = 0;
 }
 
 CHttpControlSocket::~CHttpControlSocket()
 {
 	remove_handler();
 	DoClose();
-	delete [] m_pRecvBuffer;
 }
 
 int CHttpControlSocket::SendNextCommand()
@@ -197,14 +186,13 @@ void CHttpControlSocket::OnReceive()
 
 int CHttpControlSocket::DoReceive()
 {
-	do
-	{
+	do {
 		const CSocket::SocketState state = m_pSocket->GetState();
-		if (state != CSocket::connected && state != CSocket::closing)
+		if (state != CSocket::connected && state != CSocket::closing) {
 			return 0;
+		}
 
-		if (!m_pRecvBuffer)
-		{
+		if (!m_pRecvBuffer) {
 			m_pRecvBuffer = new char[m_recvBufferLen];
 			m_recvBufferPos = 0;
 		}
@@ -212,10 +200,8 @@ int CHttpControlSocket::DoReceive()
 		unsigned int len = m_recvBufferLen - m_recvBufferPos;
 		int error;
 		int read = m_pBackend->Read(m_pRecvBuffer + m_recvBufferPos, len, error);
-		if (read == -1)
-		{
-			if (error != EAGAIN)
-			{
+		if (read == -1) {
+			if (error != EAGAIN) {
 				ResetOperation(FZ_REPLY_ERROR | FZ_REPLY_DISCONNECTED);
 			}
 			return 0;
@@ -319,22 +305,20 @@ enum filetransferStates
 	filetransfer_transfer
 };
 
-int CHttpControlSocket::FileTransfer(const wxString localFile, const CServerPath &remotePath,
-							  const wxString &remoteFile, bool download,
-							  const CFileTransferCommand::t_transferSettings&)
+int CHttpControlSocket::FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
+									std::wstring const& remoteFile, bool download,
+									CFileTransferCommand::t_transferSettings const& transferSettings)
 {
 	LogMessage(MessageType::Debug_Verbose, _T("CHttpControlSocket::FileTransfer()"));
 
 	LogMessage(MessageType::Status, _("Downloading %s"), remotePath.FormatFilename(remoteFile));
 
-	if (!download)
-	{
+	if (!download) {
 		ResetOperation(FZ_REPLY_CRITICALERROR | FZ_REPLY_NOTSUPPORTED);
 		return FZ_REPLY_ERROR;
 	}
 
-	if (m_pCurOpData)
-	{
+	if (m_pCurOpData) {
 		LogMessage(__TFILE__, __LINE__, this, MessageType::Debug_Info, _T("deleting nonzero pData"));
 		delete m_pCurOpData;
 	}
@@ -393,14 +377,13 @@ int CHttpControlSocket::FileTransferSend()
 {
 	LogMessage(MessageType::Debug_Verbose, _T("CHttpControlSocket::FileTransferSend()"));
 
-	if (!m_pCurOpData)
-	{
+	if (!m_pCurOpData) {
 		LogMessage(__TFILE__, __LINE__, this, MessageType::Debug_Info, _T("Empty m_pCurOpData"));
 		ResetOperation(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
 	}
 
-	if( !m_current_uri.HasScheme() || !m_current_uri.HasServer() || !m_current_uri.HasPath() ) {
+	if (!m_current_uri.HasScheme() || !m_current_uri.HasServer() || !m_current_uri.HasPath()) {
 		LogMessage(__TFILE__, __LINE__, this, MessageType::Debug_Warning, _T("Invalid URI: %s"), m_current_uri.BuildURI());
 		ResetOperation(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
@@ -408,39 +391,40 @@ int CHttpControlSocket::FileTransferSend()
 
 	CHttpFileTransferOpData *pData = static_cast<CHttpFileTransferOpData *>(m_pCurOpData);
 
-	if (pData->opState == filetransfer_waitfileexists)
-	{
+	if (pData->opState == filetransfer_waitfileexists) {
 		pData->opState = filetransfer_transfer;
 
 		int res = OpenFile(pData);
-		if( res != FZ_REPLY_OK)
+		if (res != FZ_REPLY_OK) {
 			return res;
+		}
 
 		res = InternalConnect(m_pCurrentServer->GetHost(), m_pCurrentServer->GetPort(), m_pCurrentServer->GetProtocol() == HTTPS);
-		if (res != FZ_REPLY_OK)
+		if (res != FZ_REPLY_OK) {
 			return res;
+		}
 	}
 
-	wxString location = m_current_uri.GetPath();
-	if( m_current_uri.HasQuery() ) {
-		location += _T("?") + m_current_uri.GetQuery();
+	std::wstring location = m_current_uri.GetPath().ToStdWstring();
+	if (m_current_uri.HasQuery()) {
+		location += L"?" + m_current_uri.GetQuery().ToStdWstring();
 	}
-	wxString action = wxString::Format(_T("GET %s HTTP/1.1"), location );
+	std::wstring action = fz::sprintf(L"GET %s HTTP/1.1", location);
 	LogMessageRaw(MessageType::Command, action);
 
-	wxString hostWithPort = m_current_uri.GetServer();
-	if( m_current_uri.HasPort() ) {
-		hostWithPort += _T(":") + m_current_uri.GetPort();
+	std::string hostWithPort = fz::to_utf8(m_current_uri.GetServer());
+	if (m_current_uri.HasPort()) {
+		hostWithPort += ":" + fz::to_utf8(m_current_uri.GetPort());
 	}
-	wxString command = wxString::Format(_T("%s\r\nHost: %s\r\nUser-Agent: %s\r\nConnection: close\r\n"), action, hostWithPort, wxString(PACKAGE_STRING, wxConvLocal));
-	if( pData->resume ) {
-		command += wxString::Format(_T("Range: bytes=%") + wxString(wxFileOffsetFmtSpec) + _T("d-\r\n"), pData->localFileSize);
+	std::string command = fz::sprintf("%s\r\nHost: %s\r\nUser-Agent: %s\r\nConnection: close\r\n", fz::to_utf8(action), hostWithPort, PACKAGE_STRING);
+	if (pData->resume) {
+		command += fz::sprintf("Range: bytes=%d-\r\n", pData->localFileSize);
 	}
-	command += _T("\r\n");
+	command += "\r\n";
 
-	const wxWX2MBbuf str = command.mb_str();
-	if (!Send(str, strlen(str)))
+	if (!Send(command.c_str(), command.size())) {
 		return FZ_REPLY_ERROR;
+	}
 
 	return FZ_REPLY_WOULDBLOCK;
 }
@@ -517,9 +501,10 @@ int CHttpControlSocket::FileTransferParseResponse(char* p, unsigned int len)
 		engine_.AddNotification(new CDataNotification(q, len));
 	}
 	else {
-		wxASSERT(pData->pFile);
+		wxASSERT(pData->file.opened());
 
-		if (pData->pFile->Write(p, len) != len) {
+		auto write = static_cast<int64_t>(len);
+		if (pData->file.write(p, write) != write) {
 			LogMessage(MessageType::Error, _("Failed to write to file %s"), pData->localFile);
 			ResetOperation(FZ_REPLY_ERROR);
 			return FZ_REPLY_ERROR;
@@ -867,21 +852,19 @@ int CHttpControlSocket::OnChunkedData(CHttpOpData* pData)
 
 int CHttpControlSocket::ResetOperation(int nErrorCode)
 {
-	if (m_pCurOpData && m_pCurOpData->opId == Command::transfer)
-	{
+	if (m_pCurOpData && m_pCurOpData->opId == Command::transfer) {
 		CHttpFileTransferOpData *pData = static_cast<CHttpFileTransferOpData *>(m_pCurOpData);
-		delete pData->pFile;
-		pData->pFile = 0;
+		pData->file.close();
 	}
 
-	if (!m_pCurOpData || !m_pCurOpData->pNextOpData)
-	{
-		if (m_pBackend)
-		{
-			if (nErrorCode == FZ_REPLY_OK)
+	if (!m_pCurOpData || !m_pCurOpData->pNextOpData) {
+		if (m_pBackend) {
+			if (nErrorCode == FZ_REPLY_OK) {
 				LogMessage(MessageType::Status, _("Disconnected from server"));
-			else
+			}
+			else {
 				LogMessage(MessageType::Error, _("Disconnected from server"));
+			}
 		}
 		ResetSocket();
 		m_pHttpOpData = 0;
@@ -930,13 +913,26 @@ void CHttpControlSocket::OnClose(int error)
 	ProcessData(0, 0);
 }
 
+void CHttpControlSocket::ResetSocket()
+{
+	delete[] m_pRecvBuffer;
+	m_pRecvBuffer = 0;
+	m_recvBufferPos = 0;
+
+	if (m_pTlsSocket) {
+		if (m_pTlsSocket != m_pBackend) {
+			delete m_pTlsSocket;
+		}
+		m_pTlsSocket = 0;
+	}
+
+	CRealControlSocket::ResetSocket();
+}
+
 void CHttpControlSocket::ResetHttpData(CHttpOpData* pData)
 {
 	wxASSERT(pData);
 
-	delete [] m_pRecvBuffer;
-	m_pRecvBuffer = 0;
-
 	pData->m_gotHeader = false;
 	pData->m_responseCode = -1;
 	pData->m_transferEncoding = CHttpOpData::unknown;
@@ -1000,16 +996,16 @@ int CHttpControlSocket::Disconnect()
 
 int CHttpControlSocket::OpenFile(CHttpFileTransferOpData* pData)
 {
-	delete pData->pFile;
-	pData->pFile = new wxFile();
+	pData->file.close();
+
 	CreateLocalDir(pData->localFile);
 
-	if (!pData->pFile->Open(pData->localFile, pData->resume ? wxFile::write_append : wxFile::write)) {
+	if (!pData->file.open(fz::to_native(pData->localFile), fz::file::writing, pData->resume ? fz::file::existing : fz::file::empty)) {
 		LogMessage(MessageType::Error, _("Failed to open \"%s\" for writing"), pData->localFile);
 		ResetOperation(FZ_REPLY_ERROR);
 		return FZ_REPLY_ERROR;
 	}
-	wxFileOffset end = pData->pFile->SeekEnd();
+	int64_t end = pData->file.seek(0, fz::file::end);
 	if (!end) {
 		pData->resume = false;
 	}
