@@ -1,13 +1,15 @@
 #include <filezilla.h>
+#include "tlssocket.h"
+
+#include <libfilezilla/time.hpp>
+
+#include <wx/utils.h>
+
 #include <gnutls/gnutls.h>
 #include <sqlite3.h>
 #include <random>
 #include <cstdint>
 
-#include <libfilezilla/time.hpp>
-
-#include "tlssocket.h"
-
 wxString GetDependencyVersion(lib_dependency d)
 {
 	switch (d) {
@@ -42,7 +44,7 @@ wxString GetDependencyName(lib_dependency d)
 	}
 }
 
-wxString ListTlsCiphers(const wxString& priority)
+std::string ListTlsCiphers(std::string const& priority)
 {
 	return CTlsSocket::ListTlsCiphers(priority);
 }
@@ -113,4 +115,4 @@ std::wstring url_encode(std::wstring const& s, bool keep_slashes)
 	}
 
 	return ret;
-}
\ No newline at end of file
+}
