@@ -274,10 +274,11 @@ wxString CServer::GetAccount() const
 	return m_account;
 }
 
-wxString CServer::GetKeyFile() const
+std::wstring CServer::GetKeyFile() const
 {
-	if (m_logonType != KEY)
-		return wxString();
+	if (m_logonType != KEY) {
+		return std::wstring();
+	}
 
 	return m_keyFile;
 }
@@ -637,36 +638,58 @@ int CServer::MaximumMultipleConnections() const
 	return m_maximumMultipleConnections;
 }
 
-wxString CServer::FormatHost(bool always_omit_port /*=false*/) const
+wxString CServer::Format(ServerFormat formatType) const
 {
-	wxString host = m_host;
+	t_protocolInfo const& info = GetProtocolInfo(m_protocol);
+	wxString server = m_host;
 
-	if (host.Find(':') != -1)
-		host = _T("[") + host + _T("]");
+	if (server.Find(':') != -1)
+		server = _T("[") + server + _T("]");
 
-	if (!always_omit_port)
-	{
-		if (m_port != GetDefaultPort(m_protocol))
-			host += wxString::Format(_T(":%d"), m_port);
+	if (formatType == ServerFormat::host_only) {
+		return server;
+	}
+	
+	if (m_port != GetDefaultPort(m_protocol)) {
+		server += wxString::Format(_T(":%d"), m_port);
 	}
 
-	return host;
-}
-
-wxString CServer::FormatServer(const bool always_include_prefix /*=false*/) const
-{
-	wxString server = FormatHost();
-
-	if (m_logonType != ANONYMOUS)
-		server = GetUser() + _T("@") + server;
-
-	const t_protocolInfo& info = GetProtocolInfo(m_protocol);
-	if (!info.prefix.empty())
-	{
-		if (always_include_prefix || info.alwaysShowPrefix)
-			server = info.prefix + _T("://") + server;
-		else if (m_port != info.defaultPort)
-			server = info.prefix + _T("://") + server;
+	if (formatType == ServerFormat::with_optional_port) {
+		return server;
+	}
+		
+	if (m_logonType != ANONYMOUS) {
+		auto user = GetUser().ToStdWstring();
+		// For now, only escape if formatting for URL.
+		// Open question: Do we need some form of escapement for presentation within the GUI,
+		// that deals e.g. with whitespace but does not touch Unicode characters?
+		if (formatType == ServerFormat::url || formatType == ServerFormat::url_with_password) {
+			user = url_encode(user);
+		}
+		if (!user.empty()) {
+			if (formatType == ServerFormat::url_with_password) {
+				auto pass = GetPass().ToStdWstring();
+				if (!pass.empty()) {
+					if (formatType == ServerFormat::url || formatType == ServerFormat::url_with_password) {
+						pass = url_encode(pass);
+					}
+					server = user + _T(":") + pass + _T("@") + server;
+				}
+			}
+			else {
+				server = url_encode(user) + _T("@") + server;
+			}
+		}
+	}
+	
+	if (formatType == ServerFormat::with_user_and_optional_port) {
+		if (!info.alwaysShowPrefix && m_port == info.defaultPort) {
+			return server;
+		}
+	}
+		
+	if (!info.prefix.empty()) {
+		server = info.prefix + _T("://") + server;
 	}
 
 	return server;
