@@ -302,14 +302,16 @@ CMainFrame::CMainFrame()
 	m_closeEventTimer.SetOwner(this);
 
 	if (CFilterManager::HasActiveFilters(true)) {
-		if (COptions::Get()->GetOptionVal(OPTION_FILTERTOGGLESTATE))
+		if (COptions::Get()->GetOptionVal(OPTION_FILTERTOGGLESTATE)) {
 			CFilterManager::ToggleFilters();
+		}
 	}
 
 	CreateMenus();
 	CreateMainToolBar();
-	if (COptions::Get()->GetOptionVal(OPTION_SHOW_QUICKCONNECT))
+	if (COptions::Get()->GetOptionVal(OPTION_SHOW_QUICKCONNECT)) {
 		CreateQuickconnectBar();
+	}
 
 	m_pAsyncRequestQueue = new CAsyncRequestQueue(this);
 
@@ -609,8 +611,10 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		CInputDialog dlg;
 		dlg.Create(this, _T("Ciphers"), _T("Priority string:"));
 		dlg.AllowEmpty(true);
-		if (dlg.ShowModal() == wxID_OK)
-			wxMessageBoxEx(ListTlsCiphers(dlg.GetValue()), _T("Ciphers"));
+		if (dlg.ShowModal() == wxID_OK) {
+			std::string ciphers = ListTlsCiphers(fz::to_string(dlg.GetValue().ToStdWstring()));
+			wxMessageBoxEx(fz::to_wstring(ciphers), _T("Ciphers"));
+		}
 	}
 	else if (event.GetId() == XRCID("ID_CLEARCACHE_LAYOUT")) {
 		CWrapEngine::ClearCache();
@@ -830,8 +834,9 @@ void CMainFrame::OnMenuHandler(wxCommandEvent &event)
 		COptions::Get()->SetOption(OPTION_COMPARISONMODE, old_mode ? 0 : 1);
 
 		CComparisonManager* pComparisonManager = pState->GetComparisonManager();
-		if (pComparisonManager && pComparisonManager->IsComparing())
+		if (pComparisonManager && pComparisonManager->IsComparing()) {
 			pComparisonManager->CompareListings();
+		}
 	}
 	else if (HandleKeyboardCommand(event, *this)) {
 		return;
@@ -1234,7 +1239,7 @@ void CMainFrame::OnClose(wxCloseEvent &event)
 	if (controls) {
 		Site site = controls->pState->GetLastSite();
 		COptions::Get()->SetLastServer(site.m_server);
-		COptions::Get()->SetOption(OPTION_LASTSERVERPATH, controls->pState->GetLastServerPath().GetSafePath());
+		COptions::Get()->SetOption(OPTION_LASTSERVERPATH, controls->pState->GetLastServerPath().GetSafePath().ToStdWstring());
 		COptions::Get()->SetOption(OPTION_LAST_CONNECTED_SITE, site.m_path);
 	}
 
@@ -1392,14 +1397,16 @@ void CMainFrame::OnSiteManager(wxCommandEvent& e)
 
 void CMainFrame::UpdateActivityLed(int direction)
 {
-	if (m_pActivityLed[direction])
+	if (m_pActivityLed[direction]) {
 		m_pActivityLed[direction]->Ping();
+	}
 }
 
 void CMainFrame::OnProcessQueue(wxCommandEvent& event)
 {
-	if (m_pQueueView)
+	if (m_pQueueView) {
 		m_pQueueView->SetActive(event.IsChecked());
+	}
 }
 
 void CMainFrame::OnMenuEditSettings(wxCommandEvent&)
@@ -1931,7 +1938,7 @@ bool CMainFrame::ConnectToSite(Site & data, Bookmark const& bookmark)
 	}
 
 	// Next tell the state to connect
-	if (!pState->Connect(data, bookmark.m_remoteDir)) {
+	if (!pState->Connect(data, bookmark.m_remoteDir, bookmark.m_comparison)) {
 		return false;
 	}
 
@@ -2080,7 +2087,7 @@ void CMainFrame::RememberSplitterPositions()
 	// m_lastQueueLogSplitterPos is a value between 0 and 1
 	posString += wxString::Format(_T("%d"), (int)(m_pQueueLogSplitter->GetRelativeSashPosition() * 1000000000));
 
-	COptions::Get()->SetOption(OPTION_MAINWINDOW_SPLITTER_POSITION, posString);
+	COptions::Get()->SetOption(OPTION_MAINWINDOW_SPLITTER_POSITION, posString.ToStdWstring());
 }
 
 bool CMainFrame::RestoreSplitterPositions()
@@ -2272,30 +2279,34 @@ void CMainFrame::ShowDropdownMenu(wxMenu* pMenu, wxToolBar* pToolBar, wxCommandE
 void CMainFrame::OnDropdownComparisonMode(wxCommandEvent& event)
 {
 	CState* pState = CContextManager::Get()->GetCurrentContext();
-	if (!pState)
+	if (!pState) {
 		return;
+	}
 
 	int old_mode = COptions::Get()->GetOptionVal(OPTION_COMPARISONMODE);
 	int new_mode = (event.GetId() == XRCID("ID_COMPARE_SIZE")) ? 0 : 1;
 	COptions::Get()->SetOption(OPTION_COMPARISONMODE, new_mode);
 
 	CComparisonManager* pComparisonManager = pState->GetComparisonManager();
-	if (old_mode != new_mode && pComparisonManager && pComparisonManager->IsComparing())
+	if (old_mode != new_mode && pComparisonManager && pComparisonManager->IsComparing()) {
 		pComparisonManager->CompareListings();
+	}
 }
 
 void CMainFrame::OnDropdownComparisonHide(wxCommandEvent&)
 {
 	CState* pState = CContextManager::Get()->GetCurrentContext();
-	if (!pState)
+	if (!pState) {
 		return;
+	}
 
 	bool old_mode = COptions::Get()->GetOptionVal(OPTION_COMPARE_HIDEIDENTICAL) != 0;
 	COptions::Get()->SetOption(OPTION_COMPARE_HIDEIDENTICAL, old_mode ? 0 : 1);
 
 	CComparisonManager* pComparisonManager = pState->GetComparisonManager();
-	if (pComparisonManager && pComparisonManager->IsComparing())
+	if (pComparisonManager && pComparisonManager->IsComparing()) {
 		pComparisonManager->CompareListings();
+	}
 }
 
 void CMainFrame::ProcessCommandLine()
@@ -2382,8 +2393,9 @@ void CMainFrame::OnFilterRightclicked(wxCommandEvent&)
 
 	CFilterManager::ToggleFilters();
 
-	if (active == CFilterManager::HasActiveFilters())
+	if (active == CFilterManager::HasActiveFilters()) {
 		return;
+	}
 
 	CContextManager::Get()->NotifyAllHandlers(STATECHANGE_APPLYFILTER);
 }
