@@ -24,6 +24,8 @@
 
 #include <algorithm>
 
+#include <libfilezilla/file.hpp>
+
 #ifdef __WXMSW__
 #include "shellapi.h"
 #include "commctrl.h"
@@ -417,7 +419,7 @@ CRemoteListView::CRemoteListView(wxWindow* pParent, CState& state, CQueueView* p
 CRemoteListView::~CRemoteListView()
 {
 	wxString str = wxString::Format(_T("%d %d"), m_sortDirection, m_sortColumn);
-	COptions::Get()->SetOption(OPTION_REMOTEFILELIST_SORTORDER, str);
+	COptions::Get()->SetOption(OPTION_REMOTEFILELIST_SORTORDER, str.ToStdWstring());
 }
 
 // See comment to OnGetItemText
@@ -1269,8 +1271,7 @@ void CRemoteListView::TransferSelectedFiles(const CLocalPath& local_parent, bool
 	if (!root.empty()) {
 		pRecursiveOperation->AddRecursionRoot(std::move(root));
 		CFilterManager filter;
-		pRecursiveOperation->StartRecursiveOperation(queue_only ? CRecursiveOperation::recursive_addtoqueue : CRecursiveOperation::recursive_transfer,
-													 filter.GetActiveFilters(false), m_pDirectoryListing->path);
+		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_transfer, filter.GetActiveFilters(), m_pDirectoryListing->path, !queue_only);
 	}
 }
 
@@ -1356,60 +1357,65 @@ void CRemoteListView::OnMenuDelete(wxCommandEvent&)
 	long item = -1;
 	for (;;) {
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-		if (!item)
+		if (!item) {
 			continue;
-		if (item == -1)
+		}
+		if (item == -1) {
 			break;
+		}
 
-		if (!IsItemValid(item))
-		{
+		if (!IsItemValid(item)) {
 			wxBell();
 			return;
 		}
 
 		int index = GetItemIndex(item);
-		if (index == -1)
+		if (index == -1) {
 			continue;
-		if (m_fileData[index].comparison_flags == fill)
+		}
+		if (m_fileData[index].comparison_flags == fill) {
 			continue;
+		}
 
 		const CDirentry& entry = (*m_pDirectoryListing)[index];
-		if (entry.is_dir())
-		{
+		if (entry.is_dir()) {
 			count_dirs++;
-			if (entry.is_link())
+			if (entry.is_link()) {
 				selected_link = true;
+			}
 		}
-		else
+		else {
 			count_files++;
+		}
 	}
 
 	wxString question;
-	if (!count_dirs)
+	if (!count_dirs) {
 		question.Printf(wxPLURAL("Really delete %d file from the server?", "Really delete %d files from the server?", count_files), count_files);
-	else if (!count_files)
+	}
+	else if (!count_files) {
 		question.Printf(wxPLURAL("Really delete %d directory with its contents from the server?", "Really delete %d directories with their contents from the server?", count_dirs), count_dirs);
-	else
-	{
+	}
+	else {
 		wxString files = wxString::Format(wxPLURAL("%d file", "%d files", count_files), count_files);
 		wxString dirs = wxString::Format(wxPLURAL("%d directory with its contents", "%d directories with their contents", count_dirs), count_dirs);
 		question.Printf(_("Really delete %s and %s from the server?"), files, dirs);
 	}
 
-	if (wxMessageBoxEx(question, _("Confirmation needed"), wxICON_QUESTION | wxYES_NO, this) != wxYES)
+	if (wxMessageBoxEx(question, _("Confirmation needed"), wxICON_QUESTION | wxYES_NO, this) != wxYES) {
 		return;
+	}
 
 	bool follow_symlink = false;
-	if (selected_link)
-	{
+	if (selected_link) {
 		wxDialogEx dlg;
-		if (!dlg.Load(this, _T("ID_DELETE_SYMLINK")))
-		{
+		if (!dlg.Load(this, _T("ID_DELETE_SYMLINK"))) {
 			wxBell();
 			return;
 		}
-		if (dlg.ShowModal() != wxID_OK)
+		if (dlg.ShowModal() != wxID_OK) {
 			return;
+		}
 
 		follow_symlink = XRCCTRL(dlg, "ID_RECURSE", wxRadioButton)->GetValue();
 	}
@@ -1417,24 +1423,28 @@ void CRemoteListView::OnMenuDelete(wxCommandEvent&)
 	CRemoteRecursiveOperation* pRecursiveOperation = m_state.GetRemoteRecursiveOperation();
 	wxASSERT(pRecursiveOperation);
 
-	std::deque<wxString> filesToDelete;
+	std::deque<std::wstring> filesToDelete;
 
 	recursion_root root(m_pDirectoryListing->path, false);
 	for (item = -1; ;) {
 		item = GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED);
-		if (!item)
+		if (!item) {
 			continue;
-		if (item == -1)
+		}
+		if (item == -1) {
 			break;
+		}
 
 		int index = GetItemIndex(item);
-		if (index == -1)
+		if (index == -1) {
 			continue;
-		if (m_fileData[index].comparison_flags == fill)
+		}
+		if (m_fileData[index].comparison_flags == fill) {
 			continue;
+		}
 
 		const CDirentry& entry = (*m_pDirectoryListing)[index];
-		const wxString& name = entry.name;
+		std::wstring const& name = entry.name;
 
 		if (entry.is_dir() && (follow_symlink || !entry.is_link())) {
 			CServerPath remotePath = m_pDirectoryListing->path;
@@ -1442,19 +1452,21 @@ void CRemoteListView::OnMenuDelete(wxCommandEvent&)
 				root.add_dir_to_visit(m_pDirectoryListing->path, name, CLocalPath(), true);;
 			}
 		}
-		else
+		else {
 			filesToDelete.push_back(name);
+		}
 	}
 
-	if (!filesToDelete.empty())
+	if (!filesToDelete.empty()) {
 		m_state.m_pCommandQueue->ProcessCommand(new CDeleteCommand(m_pDirectoryListing->path, std::move(filesToDelete)));
+	}
 
 	if (!root.empty()) {
 		pRecursiveOperation->AddRecursionRoot(std::move(root));
 		
 		CFilterManager filter;
 		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_delete,
-													 filter.GetActiveFilters(false), m_pDirectoryListing->path);
+													 filter.GetActiveFilters(), m_pDirectoryListing->path);
 	}
 }
 
@@ -1735,7 +1747,7 @@ void CRemoteListView::OnMenuChmod(wxCommandEvent&)
 		pRecursiveOperation->AddRecursionRoot(std::move(root));
 		CFilterManager filter;
 		pRecursiveOperation->StartRecursiveOperation(CRecursiveOperation::recursive_chmod,
-													 filter.GetActiveFilters(false), m_pDirectoryListing->path);
+													 filter.GetActiveFilters(), m_pDirectoryListing->path);
 
 		// Refresh listing. This gets done implicitely by the recursive operation, so
 		// only it if not recursing.
@@ -2612,7 +2624,7 @@ void CRemoteListView::OnMenuNewfile(wxCommandEvent&)
 		return;
 	}
 
-	wxString newFileName = dlg.GetValue();
+	std::wstring newFileName = dlg.GetValue().ToStdWstring();
 
 	// Check if target file already exists
 	for (unsigned int i = 0; i < m_pDirectoryListing->GetCount(); ++i) {
@@ -2624,17 +2636,16 @@ void CRemoteListView::OnMenuNewfile(wxCommandEvent&)
 
 	CEditHandler* edithandler = CEditHandler::Get(); // Used to get the temporary folder
 
-	wxString emptyfile_name = _T("empty_file_yq744zm");
-	wxString emptyfile = edithandler->GetLocalDirectory() + emptyfile_name;
+	std::wstring const emptyfile_name = L"empty_file_yq744zm";
+	std::wstring emptyfile = edithandler->GetLocalDirectory() + emptyfile_name;
 
 	// Create the empty temporary file
 	{
-		wxFile file;
-		wxLogNull log;
-		file.Create(emptyfile);
+		fz::file f(fz::to_native(emptyfile), fz::file::writing, fz::file::existing);
+		(void)f;
 	}
 
-	const CServer* pServer = m_state.GetServer();
+	CServer const* pServer = m_state.GetServer();
 	if (!pServer) {
 		wxBell();
 		return;
