@@ -139,10 +139,11 @@ void CEditHandler::RemoveTemporaryFilesInSpecificDir(wxString const& temp)
 
 }
 
-wxString CEditHandler::GetLocalDirectory()
+std::wstring CEditHandler::GetLocalDirectory()
 {
-	if (!m_localDir.empty())
+	if (!m_localDir.empty()) {
 		return m_localDir;
+	}
 
 	wxFileName tmpdir(wxFileName::GetTempDir(), _T(""));
 	// Need to call GetLongPath on MSW, GetTempDir can return short path
@@ -150,7 +151,7 @@ wxString CEditHandler::GetLocalDirectory()
 	// length
 	wxString dir = tmpdir.GetLongPath();
 	if (dir.empty() || !wxFileName::DirExists(dir))
-		return wxString();
+		return std::wstring();
 
 	if (dir.Last() != wxFileName::GetPathSeparator())
 		dir += wxFileName::GetPathSeparator();
@@ -161,14 +162,16 @@ wxString CEditHandler::GetLocalDirectory()
 	// already has the correct permissions which get inherited.
 	int i = 1;
 	do {
-		wxString newDir = dir + wxString::Format(_T("fz3temp-%d"), i++);
-		if (wxFileName::FileExists(newDir) || wxFileName::DirExists(newDir))
+		wxString newDir = dir + wxString::Format(_T("fz3temp-%d"), ++i);
+		if (wxFileName::FileExists(newDir) || wxFileName::DirExists(newDir)) {
 			continue;
+		}
 
-		if (!wxMkdir(newDir, 0700))
-			return wxString();
+		if (!wxMkdir(newDir, 0700)) {
+			return std::wstring();
+		}
 
-		m_localDir = newDir + wxFileName::GetPathSeparator();
+		m_localDir = (newDir + wxFileName::GetPathSeparator()).ToStdWstring();
 		break;
 	} while (true);
 
@@ -179,17 +182,15 @@ wxString CEditHandler::GetLocalDirectory()
 	RemoveTemporaryFiles(dir);
 
 #ifdef __WXMSW__
-	m_lockfile_handle = ::CreateFile((m_localDir + _T("fz3temp-lockfile")).wc_str(), GENERIC_WRITE, 0, 0, CREATE_NEW, FILE_ATTRIBUTE_TEMPORARY, 0);
-	if (m_lockfile_handle == INVALID_HANDLE_VALUE)
-	{
+	m_lockfile_handle = ::CreateFile((m_localDir + L"fz3temp-lockfile").c_str(), GENERIC_WRITE, 0, 0, CREATE_NEW, FILE_ATTRIBUTE_TEMPORARY, 0);
+	if (m_lockfile_handle == INVALID_HANDLE_VALUE) {
 		wxRmdir(m_localDir);
-		m_localDir = _T("");
+		m_localDir.clear();
 	}
 #else
-	wxString file = m_localDir + _T("fz3temp-lockfile");
-	m_lockfile_descriptor = open(file.mb_str(), O_CREAT | O_RDWR | O_CLOEXEC, 0600);
-	if (m_lockfile_descriptor >= 0)
-	{
+	auto file = fz::to_native(m_localDir) + "fz3temp-lockfile";
+	m_lockfile_descriptor = open(file.c_str(), O_CREAT | O_RDWR | O_CLOEXEC, 0600);
+	if (m_lockfile_descriptor >= 0) {
 		// Lock 1 byte region in the lockfile.
 		struct flock f = {};
 		f.l_type = F_WRLCK;
@@ -232,7 +233,7 @@ void CEditHandler::Release()
 	delete this;
 }
 
-enum CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName) const
+CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName) const
 {
 	std::list<t_fileData>::const_iterator iter = GetFile(fileName);
 	if (iter == m_fileDataList[local].end())
@@ -241,7 +242,7 @@ enum CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName
 	return iter->state;
 }
 
-enum CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName, const CServerPath& remotePath, const CServer& server) const
+CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName, const CServerPath& remotePath, const CServer& server) const
 {
 	std::list<t_fileData>::const_iterator iter = GetFile(fileName, remotePath, server);
 	if (iter == m_fileDataList[remote].end())
@@ -250,7 +251,7 @@ enum CEditHandler::fileState CEditHandler::GetFileState(const wxString& fileName
 	return iter->state;
 }
 
-int CEditHandler::GetFileCount(enum CEditHandler::fileType type, enum CEditHandler::fileState state, const CServer* pServer /*=0*/) const
+int CEditHandler::GetFileCount(CEditHandler::fileType type, CEditHandler::fileState state, const CServer* pServer /*=0*/) const
 {
 	int count = 0;
 	if (state == unknown) {
@@ -283,7 +284,7 @@ int CEditHandler::GetFileCount(enum CEditHandler::fileType type, enum CEditHandl
 	return count;
 }
 
-bool CEditHandler::AddFile(enum CEditHandler::fileType type, wxString& fileName, const CServerPath& remotePath, const CServer& server)
+bool CEditHandler::AddFile(CEditHandler::fileType type, wxString& fileName, const CServerPath& remotePath, const CServer& server)
 {
 	wxASSERT(type != none);
 
@@ -395,7 +396,7 @@ bool CEditHandler::RemoveAll(bool force)
 	return m_fileDataList[local].empty() && m_fileDataList[remote].empty();
 }
 
-bool CEditHandler::RemoveAll(enum fileState state, const CServer* pServer /*=0*/)
+bool CEditHandler::RemoveAll(fileState state, const CServer* pServer /*=0*/)
 {
 	// Others not implemented
 	wxASSERT(state == upload_and_remove_failed);
@@ -580,7 +581,7 @@ bool CEditHandler::StartEditing(const wxString& file, const CServerPath& remoteP
 	return StartEditing(remote, *iter);
 }
 
-bool CEditHandler::StartEditing(enum CEditHandler::fileType type, t_fileData& data)
+bool CEditHandler::StartEditing(CEditHandler::fileType type, t_fileData& data)
 {
 	wxASSERT(type != none);
 	wxASSERT(data.state == edit);
@@ -741,7 +742,7 @@ bool CEditHandler::UploadFile(const wxString& file, bool unedit)
 	return UploadFile(local, iter, unedit);
 }
 
-bool CEditHandler::UploadFile(enum fileType type, std::list<t_fileData>::iterator iter, bool unedit)
+bool CEditHandler::UploadFile(fileType type, std::list<t_fileData>::iterator iter, bool unedit)
 {
 	wxCHECK(type != none, false);
 
@@ -809,7 +810,7 @@ void CEditHandler::SetTimerState()
 		m_timer.Start(15000);
 }
 
-wxString CEditHandler::CanOpen(enum CEditHandler::fileType type, const wxString& fileName, bool &dangerous, bool &program_exists)
+wxString CEditHandler::CanOpen(CEditHandler::fileType type, const wxString& fileName, bool &dangerous, bool &program_exists)
 {
 	wxASSERT(type != none);
 
@@ -942,6 +943,7 @@ void CEditHandler::OnChangedFileEvent(wxCommandEvent&)
 
 wxString CEditHandler::GetTemporaryFile(wxString name)
 {
+	name = CQueueView::ReplaceInvalidCharacters(name);
 #ifdef __WXMSW__
 	// MAX_PATH - 1 is theoretical limit, we subtract another 4 to allow
 	// editors which create temporary files
@@ -949,41 +951,45 @@ wxString CEditHandler::GetTemporaryFile(wxString name)
 #else
 	int max = -1;
 #endif
-	if (max != -1)
-	{
+	if (max != -1) {
 		name = TruncateFilename(m_localDir, name, max);
-		if (name.empty())
+		if (name.empty()) {
 			return wxString();
+		}
 	}
 
 	wxString file = m_localDir + name;
-	if (!FilenameExists(file))
+	if (!FilenameExists(file)) {
 		return file;
+	}
 
-	if (max != -1)
+	if (max != -1) {
 		max--;
+	}
 	int cutoff = 1;
 	int n = 1;
-	while (++n < 10000) // Just to give up eventually
-	{
+	while (++n < 10000) { // Just to give up eventually
 		// Further reduce length if needed
-		if (max != -1 && n >= cutoff)
-		{
+		if (max != -1 && n >= cutoff) {
 			cutoff *= 10;
 			max--;
 			name = TruncateFilename(m_localDir, name, max);
-			if (name.empty())
+			if (name.empty()) {
 				return wxString();
+			}
 		}
 
 		int pos = name.Find('.', true);
-		if (pos < 1)
+		if (pos < 1) {
 			file = m_localDir + name + wxString::Format(_T(" %d"), n);
-		else
+		}
+		else {
 			file = m_localDir + name.Left(pos) + wxString::Format(_T(" %d"), n) + name.Mid(pos);
+		}
 
-		if (!FilenameExists(file))
+		if (!FilenameExists(file)) {
 			return file;
+		}
 	}
 
 	return wxString();
@@ -1185,7 +1191,7 @@ void CEditHandlerStatusDialog::SetCtrlState()
 	int item = -1;
 	while ((item = pListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1)
 	{
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(item, type);
 		if (pData->state == CEditHandler::edit)
 			selectedEdited = true;
@@ -1219,7 +1225,7 @@ void CEditHandlerStatusDialog::OnUnedit(wxCommandEvent&)
 	int item = -1;
 	while ((item = pListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1) {
 		pListCtrl->SetItemState(item, 0, wxLIST_STATE_SELECTED);
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(item, type);
 		if (pData->state != CEditHandler::edit && pData->state != CEditHandler::upload_and_remove_failed) {
 			wxBell();
@@ -1232,7 +1238,7 @@ void CEditHandlerStatusDialog::OnUnedit(wxCommandEvent&)
 	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter) {
 		const int i = *iter;
 
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(i, type);
 
 		if (type == CEditHandler::local) {
@@ -1266,7 +1272,7 @@ void CEditHandlerStatusDialog::OnUpload(wxCommandEvent& event)
 	while ((item = pListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1) {
 		pListCtrl->SetItemState(item, 0, wxLIST_STATE_SELECTED);
 
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(item, type);
 
 		if (pData->state != CEditHandler::edit && pData->state != CEditHandler::upload_and_remove_failed) {
@@ -1279,7 +1285,7 @@ void CEditHandlerStatusDialog::OnUpload(wxCommandEvent& event)
 	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter) {
 		const int i = *iter;
 
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(i, type);
 
 		bool unedit = event.GetId() == XRCID("ID_UPLOADANDUNEDIT") || pData->state == CEditHandler::upload_and_remove_failed;
@@ -1313,7 +1319,7 @@ void CEditHandlerStatusDialog::OnEdit(wxCommandEvent&)
 	while ((item = pListCtrl->GetNextItem(item, wxLIST_NEXT_ALL, wxLIST_STATE_SELECTED)) != -1) {
 		pListCtrl->SetItemState(item, 0, wxLIST_STATE_SELECTED);
 
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(item, type);
 
 		if (pData->state != CEditHandler::edit) {
@@ -1326,7 +1332,7 @@ void CEditHandlerStatusDialog::OnEdit(wxCommandEvent&)
 	for (std::list<int>::const_iterator iter = files.begin(); iter != files.end(); ++iter) {
 		const int i = *iter;
 
-		enum CEditHandler::fileType type;
+		CEditHandler::fileType type;
 		CEditHandler::t_fileData* pData = GetDataFromItem(i, type);
 
 		if (type == CEditHandler::local) {
@@ -1479,15 +1485,15 @@ void CNewAssociationDialog::OnOK(wxCommandEvent&)
 		}
 
 		if (always)
-			COptions::Get()->SetOption(OPTION_EDIT_DEFAULTEDITOR, _T("2") + cmd);
+			COptions::Get()->SetOption(OPTION_EDIT_DEFAULTEDITOR, _T("2") + cmd.ToStdWstring());
 		else {
 			wxString associations = COptions::Get()->GetOption(OPTION_EDIT_CUSTOMASSOCIATIONS);
 			if (!associations.empty() && associations.Last() != '\n')
 				associations += '\n';
 			if (m_ext.empty())
 				m_ext = _T("/");
-			associations += m_ext + _T(" ") + cmd;
-			COptions::Get()->SetOption(OPTION_EDIT_CUSTOMASSOCIATIONS, associations);
+			associations += m_ext.ToStdWstring() + _T(" ") + cmd.ToStdWstring();
+			COptions::Get()->SetOption(OPTION_EDIT_CUSTOMASSOCIATIONS, associations.ToStdWstring());
 		}
 	}
 	else {
@@ -1520,7 +1526,7 @@ void CNewAssociationDialog::OnOK(wxCommandEvent&)
 			if (m_ext.empty())
 				m_ext = _T("/");
 			associations += m_ext + _T(" ") + cmd;
-			COptions::Get()->SetOption(OPTION_EDIT_CUSTOMASSOCIATIONS, associations);
+			COptions::Get()->SetOption(OPTION_EDIT_CUSTOMASSOCIATIONS, associations.ToStdWstring());
 		}
 	}
 
