@@ -46,17 +46,22 @@ public:
 	{
 		all,
 		any,
-		none
+		none,
+		not_all
 	};
 
-	CFilter();
-
 	wxString name;
 
-	bool filterFiles;
-	bool filterDirs;
-	t_matchType matchType;
-	bool matchCase;
+	bool filterFiles{};
+	bool filterDirs{};
+	t_matchType matchType{all};
+
+	// Filenames on Windows ignore case
+#ifdef __WXMSW__
+	bool matchCase{};
+#else
+	bool matchCase{true};
+#endif
 
 	std::vector<CFilterCondition> filters;
 
@@ -72,6 +77,8 @@ public:
 	std::vector<bool> remote;
 };
 
+typedef std::pair<std::vector<CFilter>, std::vector<CFilter>> ActiveFilters;
+
 namespace pugi { class xml_node; }
 class CFilterManager
 {
@@ -80,26 +87,31 @@ public:
 	virtual ~CFilterManager() {}
 
 	// Note: Under non-windows, attributes are permissions
-	bool FilenameFiltered(const wxString& name, const wxString& path, bool dir, int64_t size, bool local, int attributes, fz::datetime const& date) const;
-	bool FilenameFiltered(std::vector<CFilter> const& filters, const wxString& name, const wxString& path, bool dir, int64_t size, int attributes, fz::datetime const& date) const;
-	static bool FilenameFilteredByFilter(const CFilter& filter, const wxString& name, const wxString& path, bool dir, int64_t size, int attributes, fz::datetime const& date);
+	bool FilenameFiltered(std::wstring const& name, const wxString& path, bool dir, int64_t size, bool local, int attributes, fz::datetime const& date) const;
+	bool FilenameFiltered(std::vector<CFilter> const& filters, std::wstring const& name, const wxString& path, bool dir, int64_t size, int attributes, fz::datetime const& date) const;
+	static bool FilenameFilteredByFilter(CFilter const& filter, std::wstring const& name, const wxString& path, bool dir, int64_t size, int attributes, fz::datetime const& date);
 	static bool HasActiveFilters(bool ignore_disabled = false);
 
 	bool HasSameLocalAndRemoteFilters() const;
 
 	static void ToggleFilters();
 
-	std::vector<CFilter> GetActiveFilters(bool local);
+	ActiveFilters GetActiveFilters();
 
 	static bool CompileRegexes(std::vector<CFilter>& filters);
 	static bool CompileRegexes(CFilter& filter);
 
+	static void Import(pugi::xml_node& element);
 	static bool LoadFilter(pugi::xml_node& element, CFilter& filter);
+	static void SaveFilter(pugi::xml_node& element, const CFilter& filter);
 
 protected:
 	static bool CompileRegexes();
 
 	static void LoadFilters();
+	static void LoadFilters(pugi::xml_node& element);
+	static void SaveFilters();
+
 	static bool m_loaded;
 
 	static std::vector<CFilter> m_globalFilters;
@@ -119,12 +131,7 @@ public:
 
 	bool Create(CMainFrame* parent);
 
-	static void SaveFilter(pugi::xml_node& element, const CFilter& filter);
-
 protected:
-
-	void SaveFilters();
-
 	void DisplayFilters();
 
 	void SetCtrlState();
