@@ -253,7 +253,7 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 						break;
 					}
 					else {
-						pState->ChangeRemoteDir(bookmark.m_remoteDir);
+						pState->ChangeRemoteDir(bookmark.m_remoteDir, wxString(), 0, false, bookmark.m_comparison);
 					}
 				}
 				if (!bookmark.m_localDir.empty()) {
@@ -265,6 +265,10 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 					}
 				}
 
+				if (bookmark.m_comparison && pState->GetComparisonManager()) {
+					pState->GetComparisonManager()->CompareListings();
+				}
+
 				break;
 			}
 		}
@@ -279,8 +283,9 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 		CServerPath remote_dir;
 		bool sync;
 		bool comparison;
-		if (!CBookmarksDialog::GetBookmark(iter2->second, local_dir, remote_dir, sync, comparison))
+		if (!CBookmarksDialog::GetBookmark(iter2->second, local_dir, remote_dir, sync, comparison)) {
 			return;
+		}
 
 		pState->SetSyncBrowse(false);
 		if (!remote_dir.empty() && pState->IsRemoteIdle(true)) {
@@ -291,7 +296,7 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 					wxMessageBoxEx(_("Selected global bookmark and current server use a different server type.\nUse site-specific bookmarks for this server."), _("Bookmark"), wxICON_EXCLAMATION, this);
 					return;
 				}
-				pState->ChangeRemoteDir(remote_dir);
+				pState->ChangeRemoteDir(remote_dir, _T(""), 0, false, comparison);
 			}
 		}
 		if (!local_dir.empty()) {
@@ -303,7 +308,7 @@ void CMenuBar::OnMenuEvent(wxCommandEvent& event)
 			}
 		}
 
-		if (comparison) {
+		if (comparison && pState->GetComparisonManager()) {
 			pState->GetComparisonManager()->CompareListings();
 		}
 
