@@ -759,7 +759,7 @@ bool CSiteManagerDialog::Load()
 	if (!element)
 		return true;
 
-	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED).ToStdWstring();
+	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED);
 	if (!lastSelection.empty() && lastSelection[0] == '0') {
 		if (lastSelection == _T("0"))
 			pTree->SafeSelectItem(treeId);
@@ -1463,8 +1463,9 @@ bool CSiteManagerDialog::GetServer(Site& data, Bookmark& bookmark)
 	}
 
 	CSiteManagerItemData* pData = static_cast<CSiteManagerItemData* >(pTree->GetItemData(item));
-	if (!pData)
+	if (!pData) {
 		return false;
+	}
 
 	if (pData->m_bookmark) {
 		item = pTree->GetItemParent(item);
@@ -1473,14 +1474,22 @@ bool CSiteManagerDialog::GetServer(Site& data, Bookmark& bookmark)
 		data = *pSiteData->m_site;
 		bookmark = data.m_default_bookmark;
 
-		if (!pData->m_bookmark->m_localDir.empty())
+		if (!pData->m_bookmark->m_localDir.empty()) {
 			bookmark.m_localDir = pData->m_bookmark->m_localDir;
-		if (!pData->m_bookmark->m_remoteDir.empty())
+		}
+
+		if (!pData->m_bookmark->m_remoteDir.empty()) {
 			bookmark.m_remoteDir = pData->m_bookmark->m_remoteDir;
-		if (bookmark.m_localDir.empty() || bookmark.m_remoteDir.empty())
+		}
+
+		if (bookmark.m_localDir.empty() || bookmark.m_remoteDir.empty()) {
 			bookmark.m_sync = false;
-		else
+			bookmark.m_comparison = false;
+		}
+		else {
 			bookmark.m_sync = pData->m_bookmark->m_sync;
+			bookmark.m_comparison = pData->m_bookmark->m_comparison;
+		}
 	}
 	else {
 		data = *pData->m_site;
@@ -1934,7 +1943,7 @@ bool CSiteManagerDialog::LoadDefaultSites()
 	pTree->SetItemImage(m_predefinedSites, 1, wxTreeItemIcon_Expanded);
 	pTree->SetItemImage(m_predefinedSites, 1, wxTreeItemIcon_SelectedExpanded);
 
-	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED).ToStdWstring();
+	std::wstring lastSelection = COptions::Get()->GetOption(OPTION_SITEMANAGER_LASTSELECTED);
 	if (!lastSelection.empty() && lastSelection[0] == '1') {
 		if (lastSelection == _T("1"))
 			pTree->SafeSelectItem(m_predefinedSites);
@@ -2240,7 +2249,7 @@ void CSiteManagerDialog::RememberLastSelected()
 			path = GetSitePath(sel);
 		}
 	}
-	COptions::Get()->SetOption(OPTION_SITEMANAGER_LASTSELECTED, path);
+	COptions::Get()->SetOption(OPTION_SITEMANAGER_LASTSELECTED, path.ToStdWstring());
 }
 
 void CSiteManagerDialog::OnContextMenu(wxTreeEvent& event)
