@@ -2,6 +2,7 @@
 #define __STATE_H__
 
 #include "local_path.h"
+#include "sitemanager.h"
 
 #include <memory>
 
@@ -114,15 +115,16 @@ public:
 	bool SetLocalDir(CLocalPath const& dir, wxString *error = 0, bool rememberPreviousSubdir = true);
 	bool SetLocalDir(const wxString& dir, wxString *error = 0, bool rememberPreviousSubdir = true);
 
-	bool Connect(const CServer& server, const CServerPath& path = CServerPath());
+	bool Connect(Site const& site, const CServerPath& path = CServerPath(), bool compare = false);
 	bool Disconnect();
 
-	bool ChangeRemoteDir(const CServerPath& path, const wxString& subdir = _T(""), int flags = 0, bool ignore_busy = false);
+	bool ChangeRemoteDir(const CServerPath& path, const wxString& subdir = _T(""), int flags = 0, bool ignore_busy = false, bool compare = false);
 	bool SetRemoteDir(std::shared_ptr<CDirectoryListing> const& pDirectoryListing, bool modified = false);
 	std::shared_ptr<CDirectoryListing> GetRemoteDir() const;
 	const CServerPath GetRemotePath() const;
 
-	const CServer* GetServer() const;
+	Site const& GetSite() const;
+	CServer const* GetServer() const;
 	wxString GetTitle() const;
 
 	void RefreshLocal();
@@ -163,10 +165,10 @@ public:
 	bool SetSyncBrowse(bool enable, const CServerPath& assumed_remote_root = CServerPath());
 	bool GetSyncBrowse() const { return !m_sync_browse.local_root.empty(); }
 
-	CServer GetLastServer() const { return m_last_server; }
+	Site GetLastSite() const { return m_last_site; }
 	CServerPath GetLastServerPath() const { return m_last_path; }
-	void SetLastServer(const CServer& server, const CServerPath& path)
-	{ m_last_server = server; m_last_path = path; }
+	void SetLastSite(Site const& server, CServerPath const& path)
+		{ m_last_site = server; m_last_path = path; }
 
 	bool GetSecurityInfo(CCertificateNotification *& pInfo);
 	bool GetSecurityInfo(CSftpEncryptionNotification *& pInfo);
@@ -180,17 +182,22 @@ public:
 	void ClearPreviouslyVisitedLocalSubdir() { m_previouslyVisitedLocalSubdir = _T(""); }
 	void ClearPreviouslyVisitedRemoteSubdir() { m_previouslyVisitedRemoteSubdir = _T(""); }
 
+	void UpdateSite(wxString const& oldPath, Site const& newSite);
+
 protected:
-	void SetServer(const CServer* server, CServerPath const& path = CServerPath());
+	void SetSite(Site const& site, CServerPath const& path = CServerPath());
+
+	void UpdateTitle();
 
 	CLocalPath m_localDir;
 	std::shared_ptr<CDirectoryListing> m_pDirectoryListing;
 
-	CServer* m_pServer{};
+	Site m_site;
+	
 	wxString m_title;
 	bool m_successful_connect{};
 
-	CServer m_last_server;
+	Site m_last_site;
 	CServerPath m_last_path;
 
 	CMainFrame& m_mainFrame;
@@ -213,13 +220,17 @@ protected:
 	{
 		CLocalPath local_root;
 		CServerPath remote_root;
-		bool is_changing;
-		bool compare;
 
 		// The target path when changing remote directory
 		CServerPath target_path;
 	} m_sync_browse;
 
+	struct _post_setdir
+	{
+		bool compare{};
+		bool syncbrowse{};
+	} m_changeDirFlags;
+
 	std::unique_ptr<CCertificateNotification> m_pCertificate;
 	std::unique_ptr<CSftpEncryptionNotification> m_pSftpEncryptionInfo;
 
